;; Generated package description from beframe.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "beframe" "1.3.0.0.20250627.144228" "Isolate buffers per frame" '((emacs "28.1")) :commit "9010d3df6be29833cf0f0542da70c487f2e23651" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/beframe")
